@@ -17,11 +17,12 @@ log = logging.getLogger(__name__)
 
 
 class ProtocolError(Exception):
-    """ VNC Protocol error """
+    """VNC Protocol error"""
 
 
 class MsgC2S(IntEnumLookup):
     """RFC 6143 §7.5. Client-to-Server Messages."""
+
     SET_PIXEL_FORMAT = 0
     SET_ENCODING = 2
     FRAMEBUFFER_UPDATE_REQUEST = 3
@@ -59,6 +60,7 @@ class MsgC2S(IntEnumLookup):
 
 class QemuClientMessage(IntEnumLookup):
     """https://github.com/rfbproto/rfbproto/blob/master/rfbproto.rst#qemu-client-message"""
+
     EXTENDED_KEY_EVENT = 0
     AUDIO = 1
 
@@ -94,16 +96,16 @@ class RFBServer(Protocol):  # type: ignore[misc]
     def _handle_version(self) -> None:
         msg = self.buffer[:12]
         del self.buffer[:12]
-        if not msg.startswith(b'RFB 003.') and msg.endswith(b'\n'):
+        if not msg.startswith(b"RFB 003.") and msg.endswith(b"\n"):
             self.transport.loseConnection()
 
         version = msg[8:11]
-        if version in (b'003', b'005'):
+        if version in (b"003", b"005"):
             if self.factory.password_required:
                 self._handler = self._handle_VNCAuthResponse, 16
             else:
                 self._handler = self._handle_clientInit, 1
-        elif version in (b'007', b'008'):
+        elif version in (b"007", b"008"):
             # XXX send security v3.7+
             self._handler = self._handle_security, 1
 
@@ -126,7 +128,7 @@ class RFBServer(Protocol):  # type: ignore[misc]
         self._handler = self._handle_protocol, 1
 
     def _handle_protocol(self) -> None:
-        ptype, = unpack_from('!B', self.buffer)
+        (ptype,) = unpack_from("!B", self.buffer)
         nbytes = TYPE_LEN.get(ptype, 0)
         if len(self.buffer) < nbytes:
             self._handler = self._handle_protocol, nbytes + 1
@@ -135,30 +137,30 @@ class RFBServer(Protocol):  # type: ignore[misc]
         block = bytes(self.buffer[1:nbytes])
         del self.buffer[:nbytes]
         if ptype == MsgC2S.SET_PIXEL_FORMAT:
-            (args,) = unpack('!xxx16s', block)
+            (args,) = unpack("!xxx16s", block)
             pixel_fomat = PixelFormat.from_bytes(args)
             self.handle_setPixelFormat(pixel_fomat)
         elif ptype == MsgC2S.SET_ENCODING:
-            nencodings, = unpack('!xH', block)
+            (nencodings,) = unpack("!xH", block)
             nbytes = 4 * nencodings
-            encodings = unpack_from('!' + 'I' * nencodings, self.buffer)
+            encodings = unpack_from("!" + "I" * nencodings, self.buffer)
             del self.buffer[:nbytes]
             for encoding in encodings:
                 log.debug(f"Client announces {Encoding.lookup(encoding)!r}")
             self.handle_setEncodings(encodings)
         elif ptype == MsgC2S.FRAMEBUFFER_UPDATE_REQUEST:
-            inc, x, y, w, h = unpack('!BHHHH', block)
+            inc, x, y, w, h = unpack("!BHHHH", block)
             self.handle_framebufferUpdate(x, y, w, h, inc)
         elif ptype == MsgC2S.KEY_EVENT:
-            down, key = unpack('!BxxI', block)
+            down, key = unpack("!BxxI", block)
             self.handle_keyEvent(key, down)
         elif ptype == MsgC2S.POINTER_EVENT:
-            buttonmask, x, y = unpack('!BHH', block)
+            buttonmask, x, y = unpack("!BHH", block)
             self.handle_pointerEvent(x, y, buttonmask)
         elif ptype == MsgC2S.CLIENT_CUT_TEXT:
             self.handle_clientCutText(block)
         elif ptype == MsgC2S.QEMU_CLIENT_MESSAGE:
-            subtype, = unpack('!B', block)
+            (subtype,) = unpack("!B", block)
             if subtype == QemuClientMessage.EXTENDED_KEY_EVENT:
                 self._handler = self._handle_qemuExtendedKeyEvent, 10
             else:
@@ -180,7 +182,9 @@ class RFBServer(Protocol):  # type: ignore[misc]
     def handle_setEncodings(self, encodings: Sequence[int]) -> None:
         pass
 
-    def handle_framebufferUpdate(self, x: int, y: int, w: int, h: int, incremental: bool) -> None:
+    def handle_framebufferUpdate(
+        self, x: int, y: int, w: int, h: int, incremental: bool
+    ) -> None:
         pass
 
     def handle_keyEvent(self, key: int, down: bool) -> None:
@@ -213,24 +217,25 @@ class NullTransport:
 
 
 class VNCLoggingClient(VNCDoToolClient):
-    """ Specialization of a VNCDoToolClient that will save screen captures
-    """
+    """Specialization of a VNCDoToolClient that will save screen captures"""
+
     capture_file: Optional[str] = None
 
     def commitUpdate(self, rectangles: Optional[List[Rect]] = None) -> None:
         if self.capture_file:
             assert self.screen is not None
             self.screen.save(self.capture_file)
-            self.recorder('expect %s\n' % self.capture_file)
+            self.recorder("expect %s\n" % self.capture_file)
             self.capture_file = None
 
 
 class VNCLoggingClientProxy(portforward.ProxyClient):  # type: ignore[misc]
-    """ Accept data from a server and forward to logger and downstream client
+    """Accept data from a server and forward to logger and downstream client
 
     VNC server -> VNCLoggingClientProxy -> VNC client
                                         -> VNCLoggingClient
     """
+
     vnclog: Optional[VNCLoggingClient] = None
     ncaptures = 0
 
@@ -255,11 +260,12 @@ class VNCLoggingClientFactory(portforward.ProxyClientFactory):  # type: ignore[m
 
 
 class VNCLoggingServerProxy(portforward.ProxyServer, RFBServer):  # type: ignore[misc]
-    """ Proxy in the middle, decodes and logs RFB messages before sending them upstream
+    """Proxy in the middle, decodes and logs RFB messages before sending them upstream
 
     VNC client -> VNCLoggingServerProxy -> VNC server
                                         -> RFBServer
     """
+
     clientProtocolFactory = VNCLoggingClientFactory
 
     server: Optional[str] = None
@@ -267,7 +273,7 @@ class VNCLoggingServerProxy(portforward.ProxyServer, RFBServer):  # type: ignore
     recorder: Optional[Callable[[str], int]] = None
 
     def connectionMade(self) -> None:
-        log.info('new connection from %s', self.transport.getPeer().host)
+        log.info("new connection from %s", self.transport.getPeer().host)
         super().connectionMade()
         RFBServer.connectionMade(self)
         self.mouse: Tuple[Optional[int], Optional[int]] = (None, None)
@@ -291,31 +297,31 @@ class VNCLoggingServerProxy(portforward.ProxyServer, RFBServer):  # type: ignore
 
         rev = REVERSE_MAP.get(key, chr(key))
 
-        cmds = ['pause', '%.4f' % (now - self.last_event)]
+        cmds = ["pause", "%.4f" % (now - self.last_event)]
         self.last_event = now
         if down:
-            cmds += 'keydown', rev
+            cmds += "keydown", rev
         else:
-            cmds += 'keyup', rev
-        cmds.append('\n')
+            cmds += "keyup", rev
+        cmds.append("\n")
         assert self.recorder is not None
-        self.recorder(' '.join(cmds))
+        self.recorder(" ".join(cmds))
 
     def handle_pointerEvent(self, x: int, y: int, buttonmask: int) -> None:
         now = time.time()
 
-        cmds = ['pause', '%.4f' % (now - self.last_event)]
+        cmds = ["pause", "%.4f" % (now - self.last_event)]
         self.last_event = now
         if self.mouse != (x, y):
-            cmds.append('move %d %d' % (x, y))
+            cmds.append("move %d %d" % (x, y))
             self.mouse = x, y
 
         for button in range(1, 9):
             if buttonmask & (1 << (button - 1)):
-                cmds.append('click %d' % button)
-        cmds.append('\n')
+                cmds.append("click %d" % button)
+        cmds.append("\n")
         assert self.recorder is not None
-        self.recorder(' '.join(cmds))
+        self.recorder(" ".join(cmds))
 
 
 class VNCLoggingServerFactory(portforward.ProxyFactory):  # type: ignore[misc]
@@ -336,9 +342,9 @@ class VNCLoggingServerFactory(portforward.ProxyFactory):  # type: ignore[misc]
 
     def getRecorder(self) -> Callable[[str], int]:
         if isinstance(self.output, str):
-            now = time.strftime('%y%m%d-%H%M%S')
-            outfile = os.path.join(self.output, '%s.vdo' % now)
-            self._out = open(outfile, 'w')
+            now = time.strftime("%y%m%d-%H%M%S")
+            outfile = os.path.join(self.output, "%s.vdo" % now)
+            self._out = open(outfile, "w")
             return self._out.write
         else:
             return self.output.write
